# tosclib
This library uses XML trees to generate and edit Touch OSC templates with a few custom classes and functions that help navigate the structure of the .tosc file.

**Disclaimer**: This project has no relation to Hexler, the developer of TouchOSC. Backup your templates before editing them with third party tools.

For demos: https://github.com/AlbertoV5/tosc-generate

For documentation: https://albertov5.github.io/tosc-generate
